@@ -1,7 +1,9 @@
+globalVariables("places", package="birdring", add=TRUE)
+
 place2name <-
 function (x) 
 {
-  #data(places, envir = environment())
+  data(places, envir = environment())
   placesx <- places[match(as.character(x), places$code), c(1, 2, 4), drop=TRUE]
   placesx$country <- as.factor(placesx$country)
   placesx$region <- as.factor(placesx$region)
